@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate musical cadence chords
 
-our $VERSION = '0.1304';
+our $VERSION = '0.1305';
 
 use Moo;
 use Music::Chord::Note;
@@ -255,7 +255,7 @@ Music::Cadence - Generate musical cadence chords
 
 =head1 VERSION
 
-version 0.1304
+version 0.1305
 
 =head1 SYNOPSIS
 
@@ -280,7 +280,6 @@ version 0.1304
 
   $chords = $mc->cadence(
     type      => 'imperfect',
-    octave    => 4,
     inversion => { 1 => 1, 2 => 1 },
   );
   # [B4 D4 G5], [E4 G4 C5]
@@ -460,7 +459,7 @@ the first C<half> cadence chord.  For the key of C<C major> this is:
 If an B<inversion> is defined for the C<half> cadence, the chords are
 inverted as described above for the C<imperfect> cadence.
 
-The B<evaded> cadence applies inversions to seventh chords.  The
+The C<evaded> cadence applies inversions to seventh chords.  The
 default (with no B<inversion> defined) is to invert the first chord by
 the third inversion and the second by the first inversion.
 
